==> jc-1.4.0.tar.gz: polyglot/types/ClassContextResolver.h <==
// public class polyglot.types.ClassContextResolver

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 48fe5bafe5bf6fd7 polyglot_types_ClassContextResolver
// @dep_class eec1a4cebd785b9d polyglot_types_ClassResolver

// header file dependencies
// @dep_header polyglot_types_ClassResolver

#include "polyglot/types/ClassResolver.h"

#ifndef _JC_polyglot_types_ClassContextResolver_H_
#define _JC_polyglot_types_ClassContextResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_types_Named$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_types_ClassContextResolver$sub_refs	_jc_polyglot_types_ClassContextResolver$sub_refs;
typedef struct _jc_polyglot_types_ClassContextResolver$sub_nonrefs	_jc_polyglot_types_ClassContextResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_ClassContextResolver$refs	_jc_polyglot_types_ClassContextResolver$refs;
typedef struct _jc_polyglot_types_ClassContextResolver$nonrefs	_jc_polyglot_types_ClassContextResolver$nonrefs;
typedef struct _jc_polyglot_types_ClassContextResolver$object	_jc_polyglot_types_ClassContextResolver$object;

typedef struct _jc_polyglot_types_ClassContextResolver$fields_struct	_jc_polyglot_types_ClassContextResolver$fields_struct;
typedef const struct _jc_polyglot_types_ClassContextResolver$vmethods	_jc_polyglot_types_ClassContextResolver$vmethods;
typedef const struct _jc_polyglot_types_ClassContextResolver$vtable	_jc_polyglot_types_ClassContextResolver$vtable;
typedef const struct _jc_polyglot_types_ClassContextResolver$vtype	_jc_polyglot_types_ClassContextResolver$vtype;

// Class fields structure
struct _jc_polyglot_types_ClassContextResolver$fields_struct {
	struct _jc_object	*TOPICS;
};
extern _jc_polyglot_types_ClassContextResolver$fields_struct _jc_polyglot_types_ClassContextResolver$class_fields;

// Constructors
extern void _jc_polyglot_types_ClassContextResolver$method$_init$85276e722b540669(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_ClassContextResolver$method$classType$6bb9b3afe9afc558(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *);
extern struct _jc_object *_jc_polyglot_types_ClassContextResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_types_ClassContextResolver$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_ClassContextResolver$method_info$classType$6bb9b3afe9afc558;
extern _jc_method _jc_polyglot_types_ClassContextResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_ClassContextResolver$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_polyglot_types_ClassContextResolver$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_polyglot_types_ClassContextResolver$vmethods {
	struct _jc_object	*(*classType$6bb9b3afe9afc558)(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *);
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *);
};

// Vtable
struct _jc_polyglot_types_ClassContextResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_ClassResolver$vmethods	polyglot_types_ClassResolver;
	_jc_polyglot_types_ClassContextResolver$vmethods	polyglot_types_ClassContextResolver;
};

// Vtype
struct _jc_polyglot_types_ClassContextResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_ClassContextResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_ClassContextResolver$sub_refs {
	struct _jc_object	*ts;
	struct _jc_object	*type;
};

// Reference instance fields (object)
struct _jc_polyglot_types_ClassContextResolver$refs {
    _jc_polyglot_types_ClassContextResolver$sub_refs	polyglot_types_ClassContextResolver;
    _jc_polyglot_types_ClassResolver$sub_refs	polyglot_types_ClassResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_ClassContextResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_ClassContextResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_ClassResolver$sub_nonrefs	polyglot_types_ClassResolver;
    _jc_polyglot_types_ClassContextResolver$sub_nonrefs	polyglot_types_ClassContextResolver;
};

// Object instance structure
struct _jc_polyglot_types_ClassContextResolver$object {
	_jc_polyglot_types_ClassContextResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_ClassContextResolver$vtype	*vtype;
	_jc_polyglot_types_ClassContextResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_ClassContextResolver$vtype _jc_polyglot_types_ClassContextResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_ClassContextResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_ClassContextResolver$class_object;

#endif	/* _JC_polyglot_types_ClassContextResolver_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/ClassContextResolver.h <==
// public class polyglot.types.ClassContextResolver

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 48fe5bafe5bf6fd7 polyglot_types_ClassContextResolver
// @dep_class eec1a4cebd785b9d polyglot_types_ClassResolver

// header file dependencies
// @dep_header polyglot_types_ClassResolver

#include "polyglot/types/ClassResolver.h"

#ifndef _JC_polyglot_types_ClassContextResolver_H_
#define _JC_polyglot_types_ClassContextResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_types_Named$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_types_ClassContextResolver$sub_refs	_jc_polyglot_types_ClassContextResolver$sub_refs;
typedef struct _jc_polyglot_types_ClassContextResolver$sub_nonrefs	_jc_polyglot_types_ClassContextResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_ClassContextResolver$refs	_jc_polyglot_types_ClassContextResolver$refs;
typedef struct _jc_polyglot_types_ClassContextResolver$nonrefs	_jc_polyglot_types_ClassContextResolver$nonrefs;
typedef struct _jc_polyglot_types_ClassContextResolver$object	_jc_polyglot_types_ClassContextResolver$object;

typedef struct _jc_polyglot_types_ClassContextResolver$fields_struct	_jc_polyglot_types_ClassContextResolver$fields_struct;
typedef const struct _jc_polyglot_types_ClassContextResolver$vmethods	_jc_polyglot_types_ClassContextResolver$vmethods;
typedef const struct _jc_polyglot_types_ClassContextResolver$vtable	_jc_polyglot_types_ClassContextResolver$vtable;
typedef const struct _jc_polyglot_types_ClassContextResolver$vtype	_jc_polyglot_types_ClassContextResolver$vtype;

// Class fields structure
struct _jc_polyglot_types_ClassContextResolver$fields_struct {
	struct _jc_object	*TOPICS;
};
extern _jc_polyglot_types_ClassContextResolver$fields_struct _jc_polyglot_types_ClassContextResolver$class_fields;

// Constructors
extern void _jc_polyglot_types_ClassContextResolver$method$_init$85276e722b540669(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_ClassContextResolver$method$classType$6bb9b3afe9afc558(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_types_ClassContextResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_types_ClassContextResolver$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_ClassContextResolver$method_info$classType$6bb9b3afe9afc558;
extern _jc_method _jc_polyglot_types_ClassContextResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_ClassContextResolver$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_polyglot_types_ClassContextResolver$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_types_ClassContextResolver$vmethods {
	struct _jc_object	*(*classType$6bb9b3afe9afc558)(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_types_ClassContextResolver$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_ClassContextResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_ClassResolver$vmethods	polyglot_types_ClassResolver;
	_jc_polyglot_types_ClassContextResolver$vmethods	polyglot_types_ClassContextResolver;
};

// Vtype
struct _jc_polyglot_types_ClassContextResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_ClassContextResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_ClassContextResolver$sub_refs {
	struct _jc_object	*ts;
	struct _jc_object	*type;
};

// Reference instance fields (object)
struct _jc_polyglot_types_ClassContextResolver$refs {
    _jc_polyglot_types_ClassContextResolver$sub_refs	polyglot_types_ClassContextResolver;
    _jc_polyglot_types_ClassResolver$sub_refs	polyglot_types_ClassResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_ClassContextResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_ClassContextResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_ClassResolver$sub_nonrefs	polyglot_types_ClassResolver;
    _jc_polyglot_types_ClassContextResolver$sub_nonrefs	polyglot_types_ClassContextResolver;
};

// Object instance structure
struct _jc_polyglot_types_ClassContextResolver$object {
	_jc_polyglot_types_ClassContextResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_ClassContextResolver$vtype	*vtype;
	_jc_polyglot_types_ClassContextResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_ClassContextResolver$vtype _jc_polyglot_types_ClassContextResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_ClassContextResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_ClassContextResolver$class_object;

#endif	/* _JC_polyglot_types_ClassContextResolver_H_ */
